/* 
 * Copyright (c) 2010, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

/*
 *  ======== tal_gpp.h ========
 *
 *  TAL module definitions (GPP side).
 *
 */


#if !defined (TAL_GPP_H)
#define TAL_GPP_H

#if defined (__cplusplus)
extern "C" {
#endif /* defined (__cplusplus) */


// typedef Void (*FnTalCbck)(Void * arg, Uint16 event, Uint16 payload);
typedef void (*FnTalCbck)(
        void * arg,
        unsigned short event,
        unsigned short payload);

typedef enum {
    TAL_SOK = 0,
    TAL_EFAIL
} TAL_Status;

typedef enum {
    TAL_AVAILABLE = 0,
    TAL_UNAVAILABLE
} TAL_TransportState;

typedef struct TalObject_tag {
//  Uint32              dspId;
    unsigned long       dspId;
    FnTalCbck           cbckFxn;
//  Pvoid               cbckArg;
    void                *cbckArg;
} TalObject, *TAL_Handle;


/*
 *  ======== TAL_changeState ========
 *  Change the availability state of the data transport.
 */
/* TODO add handle argument */
TAL_Status TAL_changeState (TAL_TransportState newstate,
    TAL_TransportState * oldState);


/*
 *  ======== TAL_close ========
 *  Breaks connection with data transport.
 */
TAL_Status TAL_close (TAL_Handle handle);


/*
 *  ======== TAL_getDSPAddress ========
 *  Fetch the DSP address corresponding to a symbol.
 */
TAL_Status TAL_getDSPAddress (
        TAL_Handle handle,
//      Pstr symbol,
        char *symbol,
//      Uint32 * address);
        unsigned long * address);


/*
 *  ======== TAL_open ========
 *  Establish a connection with the data transport.
 */
TAL_Status TAL_open (
//      Pstr name,
        char *name,
        TAL_Handle *handle);


/*
 *  ======== TAL_registerEvents ========
 *  Register a function to be called when a power event is recieved over the
 *  data transport.
 */
TAL_Status TAL_registerEvents (
        TAL_Handle handle,
        FnTalCbck callback,
//      Pvoid arg);
        void *arg);


/*
 *  ======== TAL_sendEvent ========
 *  Send a power-related event over the data transport.
 */
TAL_Status TAL_sendEvent (
        TAL_Handle handle,
//      Uint16 event,
        unsigned short event,
//      Uint16 payload);
        unsigned short payload);


/*
 *  ======== TAL_unregisterEvents ========
 *  Unregiter for callbacks on power events.
 */
TAL_Status TAL_unregisterEvents (TAL_Handle handle);


/* IPS channel values. Must agree with tal_dsp.h */
#define IPS_ID_POWER 0 
#define IPS_EVENT_POWER 4


#if defined (__cplusplus)
}
#endif /* defined (__cplusplus) */


#endif /* !defined (TAL_GPP_H) */
/*
 *  @(#) ti.bios.power; 1, 1, 1,1; 4-30-2010 13:19:46; /db/atree/library/trees/power/power-g09x/src/
 */

